summaryrefslogtreecommitdiff
path: root/mjit_worker.c
diff options
context:
space:
mode:
Diffstat (limited to 'mjit_worker.c')
-rw-r--r--mjit_worker.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/mjit_worker.c b/mjit_worker.c
index 306c8cbc71..6d9ce697e0 100644
--- a/mjit_worker.c
+++ b/mjit_worker.c
@@ -1396,9 +1396,9 @@ unload_units(void)
void
mjit_worker(void)
{
// Allow only `max_cache_size / 10` times (default: 10) of compaction.
// Note: GC of compacted code has not been implemented yet.
- int max_compact_size = mjit_opts.max_cache_size / 10;
+ int max_compact_size = mjit_opts.max_cache_size / 100;
if (max_compact_size < 10) max_compact_size = 10;
// Run unload_units after it's requested `max_cache_size / 10` (default: 10) times.
@@ -1396,9 +1396,9 @@ unload_units(void)
mjit_worker(void)
{
- // Allow only `max_cache_size / 10` times (default: 10) of compaction.
+ // Allow only `max_cache_size / 100` times (default: 100) of compaction.
// Note: GC of compacted code has not been implemented yet.